'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getRepositoryVersion = getRepositoryVersion;
exports.getRepositoryBranch = getRepositoryBranch;
exports.getRepositoryRemoteURL = getRepositoryRemoteURL;
exports.getRepositoryRemoteUsername = getRepositoryRemoteUsername;
exports.getRepositoryName = getRepositoryName;
exports.refreshRepo = refreshRepo;
exports.checkoutBranch = checkoutBranch;
exports.createBranch = createBranch;
exports.createCommit = createCommit;

var _child_process = require('child_process');

function getRepositoryVersion() {
  return (0, _child_process.execSync)('git describe --tags --abbrev=0', { encoding: 'utf8' }).trim();
}

function getRepositoryBranch() {
  return (0, _child_process.execSync)('git rev-parse --abbrev-ref HEAD', { encoding: 'utf8' }).trim();
}

function getRepositoryRemoteURL() {
  return (0, _child_process.execSync)('git config --get remote.origin.url', { encoding: 'utf8' }).trim();
}

function getRepositoryRemoteUsername() {
  const url = getRepositoryRemoteURL();

  if (url.includes('https')) {
    return url.split('/').reverse()[1].trim();
  }

  return url.split(':')[1].split('/')[0].trim();
}

function getRepositoryName() {
  return getRepositoryRemoteURL().split('/').pop().trim().replace('.git', '');
}

function refreshRepo() {
  return (0, _child_process.execSync)('git fetch', { encoding: 'utf8' });
}

function checkoutBranch(branchName) {
  return (0, _child_process.execSync)(`git checkout ${branchName}`, { encoding: 'utf8' });
}

function createBranch(branchName) {
  return (0, _child_process.execSync)(`git checkout -b ${branchName}`, { encoding: 'utf8' });
}

function createCommit(message) {
  return (0, _child_process.execSync)(`git commit -m "${message}"`, { encoding: 'utf8' });
}
//# sourceMappingURL=git.js.map